@@ -4,13 +4,13 @@ Functions for performing ephemeris searches
 
 import datetime
 import humanize
-import warnings
 from typing import Dict, List, Optional
 from .classes.ephemeris import Ephemeris
 from .classes.search import Search
 from ..sources import (DataSource,
                        list as sources_list)
-from ..exceptions import (AuroraXValidationException,
+from ..exceptions import (AuroraXSearchException,
+                          AuroraXValidationException,
                           AuroraXUploadException,
                           AuroraXBadParametersException)
 from ..requests import STANDARD_POLLING_SLEEP_TIME
@@ -133,6 +133,11 @@ def search(start: datetime.datetime,
         print("[%s] Waiting for data ..." % (datetime.datetime.now()))
     s.wait(poll_interval=poll_interval, verbose=verbose)
 
+    # check if error condition encountered
+    if (s.status["search_result"]["error_condition"] is True):
+        # error encountered
+        raise AuroraXSearchException(s.logs[-1]["summary"])
+
     # get the data
     if (verbose is True):
         print("[%s] Retrieving data ..." % (datetime.datetime.now()))
@@ -147,72 +152,6 @@ def search(start: datetime.datetime,
     return s
 
 
-def search_async(start: datetime.datetime,
-                 end: datetime.datetime,
-                 programs: Optional[List[str]] = None,
-                 platforms: Optional[List[str]] = None,
-                 instrument_types: Optional[List[str]] = None,
-                 metadata_filters: Optional[List[Dict]] = None,
-                 metadata_filters_logical_operator: Optional[str] = None,
-                 response_format: Optional[Dict] = None) -> Search:
-    """
-    Submit a request for a ephemeris search, return immediately.
-
-    The request will be done asynchronously by the API. Use the helper functions
-    as part of the Search object returned to check for data and/or download it.
-    If you don't want the search to return immediately and rather block until
-    all data is downloaded, please use the 'search' function instead.
-
-    Note: At least one search criteria from programs, platforms, or
-    instrument_types, must be specified.
-
-    .. deprecated::
-        This function is deprecated as of 0.9.0. Please use the 'search' function
-        with the 'return_immediately' flag set to True to get the same behaviour.
-        This function will be removed in a future release.
-
-    Args:
-        start: start timestamp of the search (inclusive)
-        end: end timestamp of the search (inclusive)
-        programs: list of programs to search through, defaults to None
-        platforms: list of platforms to search through, defaults to None
-        instrument_types: list of instrument types to search through, defaults to None
-        metadata_filters: list of dictionaries describing metadata keys and
-            values to filter on, defaults to None
-
-            Example:
-
-                [{
-                    "key": "nbtrace_region",
-                    "operator": "in",
-                    "values": ["north polar cap"]
-                }]
-        metadata_filters_logical_operator: the logical operator to use when
-            evaluating metadata filters (either 'AND' or 'OR'), defaults
-            to "AND"
-        response_format: JSON representation of desired data response format
-
-    Returns:
-        A pyaurorax.ephemeris.Search object
-
-    Raises:
-        pyaurorax.exceptions.AuroraXBadParametersException: missing parameters
-    """
-    warnings.warn("This function is deprecated and will be removed in a future release. Please "
-                  "use the 'search' function with the 'return_immediately' flag to produce the "
-                  "same behaviour.", DeprecationWarning, stacklevel=2)
-    s = Search(start,
-               end,
-               programs=programs,
-               platforms=platforms,
-               instrument_types=instrument_types,
-               metadata_filters=metadata_filters,
-               metadata_filters_logical_operator=metadata_filters_logical_operator,
-               response_format=response_format)
-    s.execute()
-    return s
-
-
 def upload(identifier: int,
            records: List[Ephemeris],
            validate_source: Optional[bool] = False) -> int:
@@ -225,7 +164,7 @@ def upload(identifier: int,
         validate_source: validate all records before uploading, defaults to False
 
     Returns:
-        1 for success, raises exception on error
+        0 for success, raises exception on error
 
     Raises:
         pyaurorax.exceptions.AuroraXMaxRetriesException: max retry error
@@ -260,7 +199,7 @@ def upload(identifier: int,
                                                   res.data["error_message"]))
 
     # return
-    return 1
+    return 0
 
 
 def delete(data_source: DataSource,
@@ -279,7 +218,7 @@ def delete(data_source: DataSource,
         end: timestamp marking end of range to delete records for, inclusive
 
     Returns:
-        1 on success
+        0 on success
 
     Raises:
         pyaurorax.exceptions.AuroraXMaxRetriesException: max retry error
@@ -317,7 +256,7 @@ def delete(data_source: DataSource,
                                                          res.data["error_message"]))
 
     # return
-    return 1
+    return 0
 
 
 def describe(search_obj: Search) -> str:
@@ -332,7 +271,7 @@ def describe(search_obj: Search) -> str:
     """
     # make request
     req = AuroraXRequest(method="post",
-                         url=urls.describe_ephemeris_query,
+                         url=urls.describe_ephemeris_query_url,
                          body=search_obj.query)
     res = req.execute()
 
