@@ -10,11 +10,14 @@ here instead of digging in deeper to the submodules.
 # function and class imports
 from .requests import (FIRST_FOLLOWUP_SLEEP_TIME,
                        STANDARD_POLLING_SLEEP_TIME,
+                       ALLOWED_SEARCH_LISTING_TYPES,
                        get_data,
                        get_logs,
                        get_status,
                        wait_for_data,
-                       cancel)
+                       cancel,
+                       list,
+                       delete)
 
 # pdoc imports and exports
 from .requests import __pdoc__ as __requests_pdoc__
@@ -22,9 +25,12 @@ __pdoc__ = __requests_pdoc__
 __all__ = [
     "FIRST_FOLLOWUP_SLEEP_TIME",
     "STANDARD_POLLING_SLEEP_TIME",
+    "ALLOWED_SEARCH_LISTING_TYPES",
     "get_data",
     "get_logs",
     "get_status",
     "wait_for_data",
     "cancel",
+    "list",
+    "delete",
 ]
